.. include:: ../references.txt

Image Alignment and Registering
===============================

.. TODO:: Write registering documentation

Registering API
---------------

.. automodapi:: astropop.image.register
    :no-inheritance-diagram:
